
Kalpy documentation
===================

.. grid:: 2

    .. grid-item-card:: Getting started
       :text-align: center

       :fas:`running;fa-6x i-navigation`

       ^^^

       Install Kalpy and get started with examples and tutorials.

       +++

       .. button-ref:: getting_started
          :expand:
          :color: primary

          Install Kalpy

    .. grid-item-card:: First steps
       :text-align: center

       :fas:`terminal;fa-6x i-navigation`

       ^^^

       Have a particular use case for Kalpy?

       Check out the first steps tutorials.

       +++

       .. button-ref:: first_steps
          :expand:
          :color: primary

          First steps

    .. grid-item-card:: User guide
       :text-align: center

       :fas:`book-open;fa-6x i-navigation`

       ^^^

       The User Guide gives more details on interacting with Kalpy.

       +++

       .. button-ref:: user_guide
          :expand:
          :color: primary

          User guide

    .. grid-item-card:: API reference
       :text-align: center

       :fas:`file-code;fa-6x i-navigation`

       ^^^

       Kalpy API reference

       +++

       .. button-ref:: mfa_api
          :expand:
          :color: primary

          Reference guide

.. toctree::
   :hidden:

   Getting started <getting_started.rst>
   User guide <user_guide/index.rst>
   API reference <reference/index.rst>
   Changelog <changelog.rst>
